@@ -23,6 +23,12 @@ has unique => (
     default => '',
 );
 
+has job_handle => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => '',
+);
+
 has [qw/on_created on_data on_complete on_fail on_status on_warning/] => (
     is      => 'rw',
     isa     => 'CodeRef',
@@ -55,13 +61,14 @@ sub BUILD {
 }
 
 sub pack_req {
-    my $self = shift;
+    my ($self, $type) = @_;
+    $type = $type && $type eq 'bg'? SUBMIT_JOB_BG : SUBMIT_JOB;
 
     my $data = $self->function . "\0"
              . $self->unique . "\0"
              . $self->workload;
 
-    "\0REQ" . pack('NN', SUBMIT_JOB, length($data)) . $data;
+    "\0REQ" . pack('NN', $type, length($data)) . $data;
 }
 
 sub pack_option_req {
@@ -88,6 +95,8 @@ AnyEvent::Gearman::Task - gearman task
 
 Daisuke Murase <typester@cpan.org>
 
+Pedro Melo <melo@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2009 by KAYAC Inc.
